==> hermes-2.4.12.8.tar.gz: hermes-2.4.12.8/config/initializers/notifications_key.rb <==
# frozen_string_literal: true

# Wrike task and informations
# https://www.wrike.com/open.htm?id=497548612
NOTIFICATION_KEYS = {
  applicant: {
    new_eligible_offers: 'applicant.new.eligible_offers', # Devops 7134
  },
  housing_offer: {
    new_eligible_offer: 'housing_offer.new.eligible', # 5495 + 5508
    position_decreased: 'housing_offer.position.decreased' # 5538
  },
  nud: {
    create: 'nud.create' # 5518 + 5605
  },
  user: {
    create: 'user.create' # 5601 + 5602
  },
  housing_request: {
    al_edit: 'housing_request.al.edit', # 5624
    applicant_edit: 'housing_request.applicant.edit', # 5610
    status_change: 'housing_request.status.change',
    delegation_signed_required: 'housing_request.delegation.signed_required',
    custom: 'housing_request.custom.notification',
    entity_validated: 'housing_request.entity.validated', # 5524 + 5611
    documents_consultation_ko: 'housing_request.documents_consultation.ko', # 5526 + 5606
    documents_application_ko: 'housing_request.documents_application.ko', # 5622 + 5619
    documents_application_missing: 'housing_request.documents_application.missing', # 5629 + 5628
    request_completed: 'housing_request.request.completed', # 5603 (front only)
    request_incompleted: 'housing_request.request.incompleted', # 5604
    documents_missing: 'housing_request.documents.missing', # 5618
    application_delay_exceeded: 'housing_request.application.delay_exceeded' # 5855 + 5858
  },
  housing_application: {
    lessor_withdrawal: 'housing_application.lessor.withdrawal', # 5528 + 5623
    lessor_transferred: 'housing_application.lessor.transferred', # 5528 + 5623
    lessor_accepted: 'housing_application.lessor.accepted', # 5535 + 5630 CONFLICT_1
    lessor_cancelled: 'housing_application.lessor.cancelled', # 5532 + 5626
    lessor_denied: 'housing_application.lessor.denied', # 5536 + 5632
    cal_denied: 'housing_application.cal.denied', # 5531 + 5625
    pending: 'housing_application.status.pending', # 5619
    subscribed: 'housing_application.status.subscribed', # 5620 (front only)
    applicant_cancelled: 'housing_application.applicant.cancelled', # 5621 (front only)
    applicant_cancelled_after_visit: 'housing_application.applicant.cancelled_after_visit' # 5836 (front only)
  }
}.freeze

==> hermes-5.3.0.14.tar.gz: hermes-5.3.0.14/config/initializers/notifications_key.rb <==
# frozen_string_literal: true

# Wrike task and informations
# https://www.wrike.com/open.htm?id=497548612
NOTIFICATION_KEYS = {
  applicant: {
    new_eligible_offers: 'applicant.new.eligible_offers', # Devops 7134
  },
  housing_offer: {
    new_eligible_offer: 'housing_offer.new.eligible', # 5495 + 5508
    position_decreased: 'housing_offer.position.decreased' # 5538
  },
  nud: {
    create: 'nud.create' # 5518 + 5605
  },
  user: {
    create: 'user.create', # 5601 + 5602
    new_reserved_offer: 'user.new_reserved_offer'
  },
  housing_request: {
    al_edit: 'housing_request.al.edit', # 5624
    applicant_edit: 'housing_request.applicant.edit', # 5610
    status_change: 'housing_request.status.change',
    delegation_signed_required: 'housing_request.delegation.signed_required',
    custom: 'housing_request.custom.notification',
    entity_validated: 'housing_request.entity.validated', # 5524 + 5611
    documents_consultation_ko: 'housing_request.documents_consultation.ko', # 5526 + 5606
    documents_application_ko: 'housing_request.documents_application.ko', # 5622 + 5619
    documents_application_missing: 'housing_request.documents_application.missing', # 5629 + 5628
    request_completed: 'housing_request.request.completed', # 5603 (front only)
    request_incompleted: 'housing_request.request.incompleted', # 5604
    documents_missing: 'housing_request.documents.missing', # 5618
    application_delay_exceeded: 'housing_request.application.delay_exceeded', # 5855 + 5858
  },
  housing_application: {
    lessor_withdrawal: 'housing_application.lessor.withdrawal', # 5528 + 5623
    lessor_transferred: 'housing_application.lessor.transferred', # 5528 + 5623
    lessor_accepted: 'housing_application.lessor.accepted', # 5535 + 5630 CONFLICT_1
    lessor_cancelled: 'housing_application.lessor.cancelled', # 5532 + 5626
    lessor_denied: 'housing_application.lessor.denied', # 5536 + 5632
    cal_denied: 'housing_application.cal.denied', # 5531 + 5625
    pending: 'housing_application.status.pending', # 5619
    subscribed: 'housing_application.status.subscribed', # 5620 (front only)
    applicant_cancelled: 'housing_application.applicant.cancelled', # 5621 (front only)
    applicant_cancelled_after_visit: 'housing_application.applicant.cancelled_after_visit' # 5836 (front only)
  }
}.freeze
